@@ -1,21 +1,18 @@
-# -*- coding: utf-8 -*-
-
 import nose.tools as nt
-from pyee import Event_emitter, EventEmitter
-
+from pyee import EventEmitter
 
+# An exception, used to prove that an event handler fired.
+# Kinda hack-y, I know.
 class ItWorkedException(Exception):
-    """An exception, used to prove that an event handler fired.
-    Kinda hack-y, I know.
-    """
     pass
 
 def test_emit():
-    """Test that event_emitters fire properly.
     """
-    ee = Event_emitter()
+    Test to show that event_emitters fire properly.
+    """
+    ee = EventEmitter()
 
-    # Used in a decorator style
+    #Used in a decorator style.
     @ee.on('event')
     def event_handler(data, **kwargs):
         nt.assert_equals(data, 'emitter is emitted!')
@@ -23,47 +20,22 @@ def test_emit():
         if (kwargs['error']):
             raise ItWorkedException
 
-    # Making sure data is passed propers
+    #Making sure data is passed propers.
     ee.emit('event', 'emitter is emitted!', error=False)
 
-    # Some nose bullshit to check for the firings. 
-    # "Hides" other exceptions.
+    # Some nose bullshit to check for the firings. "Hides" other exceptions.
     with nt.assert_raises(ItWorkedException) as it_worked:
         ee.emit('event', 'emitter is emitted!', error=True)
 
-def test_emit_error():
-    ee = EventEmitter()
-    
-    with nt.assert_raises(Exception):
-        ee.emit('error')
-
-    @ee.on('error')
-    def onError():
-        pass
-        
-    # No longer raises and error instead return True indicating handled
-    nt.assert_true(ee.emit('error'))
-
-def test_emit_return():
-    ee = EventEmitter()
-    
-    # make sure emitting without a callback returns False
-    nt.assert_false(ee.emit('data'))
-
-    # add a callback
-    ee.on('data')(lambda: None)
-
-    # should return True now
-    nt.assert_true(ee.emit('data'))
-
 def test_new_listener_event():
-    """Test the 'new_listener' event.
+    """
+    test for the 'new_listener' event
     """
 
-    ee = Event_emitter()
+    ee = EventEmitter()
 
     @ee.on('new_listener')
-    def new_listener_handler(event, fxn):
+    def new_listener_handler():
         raise ItWorkedException
 
     with nt.assert_raises(ItWorkedException) as it_worked:
@@ -73,53 +45,48 @@ def test_new_listener_event():
 
     
 def test_listener_removal():
-    """Tests that we can remove listeners (as appropriate).
+    """
+    tests to make sure we can remove listeners as appropriate.
     """
 
-    ee = Event_emitter()
+    ee = EventEmitter()
 
 
     #Some functions to pass to the EE
     def first():
         return 1
 
-    ee.on('event', first)
-
-    @ee.on('event')
     def second():
         return 2
 
-    @ee.on('event')
     def third():
         return 3
 
-    def fourth():
-        return 4
+    #If you want un-closed functions, you unfortunately have to
+    #call ee without using decorator styles.
+    ee.on('event', first)
+    ee.on('event', second)
+    ee.on('event', third)
 
-    ee.on('event', fourth)
+    nt.assert_equal(ee._events['event'], [first, second, third])
 
-    nt.assert_equal(ee._events['event'], [first, second, third, fourth])
-
-    # uses the function itself to find/remove listener
+    #uses the function itself to find/remove listener
     ee.remove_listener('event', second)
-    nt.assert_equal(ee._events['event'], [first, third, fourth])
+    nt.assert_equal(ee._events['event'], [first, third])
 
-    # uses the function itself to find/remove listener
-    ee.remove_listener('event', first)
-    nt.assert_equal(ee._events['event'], [third, fourth])
-
-    # Remove ALL listeners!
+    #remove ALL the listeners!
     ee.remove_all_listeners('event')
     nt.assert_equal(ee._events['event'], [])
 
 def test_once():
-    """Test that `once()` method works propers.
+    """
+    Test to show that the "once" method works propers.
     """
 
     # very similar to "test_emit" but also makes sure that the event
     # gets removed afterwards
 
-    ee = Event_emitter()
+    ee = EventEmitter()
 
     def once_handler(data, error=None):
         nt.assert_equals(data, 'emitter is emitted!')
@@ -137,10 +104,10 @@ def test_once():
         ee.emit('event', 'emitter is emitted!', True)
 
 def test_listeners():
-    """Test that `listeners()` gives you access to the listeners array.
     """
-    
-    ee = Event_emitter()
+    Test to make sure that the listeners method gives you access to the listeners array.
+    """
+    ee = EventEmitter()
     @ee.on('event')
     def event_handler():
         pass
